.. include:: ./hello.rst

Get started
-----------

.. toctree::
   :maxdepth: 2

   installation
   usage
   contributing
   authors
   history


License
-------

MIT


Author
------

Scott Doucet / Duroktar / traBpUkciP

Credits
-------

`pluginbase <http://pluginbase.pocoo.org/>`_   - For backend plugins

`Cookicutter <https://github.com/audreyr/cookiecutter-pypackage>`_ - For package layout
